@@ -393,24 +393,28 @@ copy_archive_ok_cb (GtkWidget    *w,
 {
 	FRWindow   *window;
 	const char *path;
-	char       *new_filename;
+	const char *filename;
+	char       *folder;
+	char       *new_path;
 
 	gtk_widget_hide (data->file_sel);
 
 	window = data->window;
 	path = gtk_file_selection_get_filename (GTK_FILE_SELECTION (data->file_sel));
 
-	if (path == NULL) {
+	if ((path == NULL) || (*path == 0)) {
                 gtk_widget_destroy (data->file_sel);
 		return;
 	}
 
-	if (path[strlen (path) - 1] == '/')
-		new_filename = g_strconcat (path, file_name_from_path (window->archive_filename), NULL);
-	else
-		new_filename = g_strconcat (path, "/", file_name_from_path (window->archive_filename), NULL);
+	filename = file_name_from_path (path);
+	if ((filename == NULL) || (*filename == 0))
+		filename = file_name_from_path (window->archive_filename);
+	folder = remove_level_from_path (path);
+	new_path = g_build_filename (folder, filename, NULL);
+	g_free (folder);
 
-	if (path_is_file (new_filename)) {
+	if (path_is_file (new_path)) {
 		GtkWidget *d;
 		int        r;
 
@@ -426,7 +430,7 @@ copy_archive_ok_cb (GtkWidget    *w,
 		gtk_widget_destroy (GTK_WIDGET (d));
 		
 		if (r != GTK_RESPONSE_YES) {
-			g_free (new_filename);
+			g_free (new_path);
 			gtk_widget_destroy (data->file_sel);
 			return;
 		}
@@ -434,9 +438,9 @@ copy_archive_ok_cb (GtkWidget    *w,
 	
 	if (data->copy) {
 #ifdef DEBUG
-		g_print ("cp %s %s\n", window->archive_filename, new_filename);
+		g_print ("cp %s %s\n", window->archive_filename, new_path);
 #endif
-		if (! file_copy (window->archive_filename, new_filename)) {
+		if (! file_copy (window->archive_filename, new_path)) {
 			GtkWidget *dialog;
 			dialog = gtk_message_dialog_new (GTK_WINDOW (window->app),
 							 GTK_DIALOG_DESTROY_WITH_PARENT,
@@ -448,10 +452,10 @@ copy_archive_ok_cb (GtkWidget    *w,
 		}
 	} else {
 #ifdef DEBUG
-		g_print ("mv %s %s\n", window->archive_filename, new_filename);
+		g_print ("mv %s %s\n", window->archive_filename, new_path);
 #endif
-		if (file_move (window->archive_filename, new_filename)) 
-			window_archive_rename (window, new_filename);
+		if (file_move (window->archive_filename, new_path)) 
+			window_archive_rename (window, new_path);
 		else {
 			GtkWidget *dialog;
 			dialog = gtk_message_dialog_new (GTK_WINDOW (window->app),
@@ -464,7 +468,7 @@ copy_archive_ok_cb (GtkWidget    *w,
 		}
 	}
 
-	g_free (new_filename);
+	g_free (new_path);
 	gtk_widget_destroy (data->file_sel);
 }
 
@@ -775,7 +779,9 @@ about_cb (GtkWidget *widget,
 		"Paolo Bacchilega <paolo.bacch@tin.it>", NULL
 	};
 	const char       *documenters [] = {
-		"Alexander Kirillov", NULL
+		"Alexander Kirillov", 
+		"Breda McColgan",
+		NULL
 	};
 	const char       *translator_credits = _("translator_credits");
 
